@@ -11,8 +11,7 @@ class Client:
 
 
     async def getVehicles(self):
-        vehicles = await self._connection.get("https://connect-portal.porsche.com/core/api/v3/de/de_DE/vehicles",
-                application='portal')
+        vehicles = await self._connection.get("https://connect-portal.porsche.com/core/api/v3/de/de_DE/vehicles")
         return vehicles
 
 
